# emojipy
Python library for working with emojione, install via pip

cloned from 

https://github.com/Ranks/emojione/tree/master/lib/python/emojipy

https://github.com/Ranks/emojione

```
pip install emojipy
```
